import typing_extensions

from sedaro_base_client.paths import PathValues
from sedaro_base_client.apis.paths.models_branches_branch_id_system_satellite_block_id import ModelsBranchesBranchIdSystemSatelliteBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_body_frame_vectors_ import ModelsBranchesBranchIdSystemGeometryBodyFrameVectors
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_body_frame_vectors_block_id import ModelsBranchesBranchIdSystemGeometryBodyFrameVectorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_surfaces_ import ModelsBranchesBranchIdSystemGeometrySurfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_surfaces_block_id import ModelsBranchesBranchIdSystemGeometrySurfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_surfaces_materials_ import ModelsBranchesBranchIdSystemGeometrySurfacesMaterials
from sedaro_base_client.apis.paths.models_branches_branch_id_system_geometry_surfaces_materials_block_id import ModelsBranchesBranchIdSystemGeometrySurfacesMaterialsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_ import ModelsBranchesBranchIdSystemSubsystems
from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_block_id import ModelsBranchesBranchIdSystemSubsystemsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_components_ import ModelsBranchesBranchIdSystemSubsystemsComponents
from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_components_block_id import ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_ import ModelsBranchesBranchIdSystemLoads
from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_block_id import ModelsBranchesBranchIdSystemLoadsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_states_ import ModelsBranchesBranchIdSystemLoadsStates
from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_states_block_id import ModelsBranchesBranchIdSystemLoadsStatesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_operational_modes_ import ModelsBranchesBranchIdCdhConopsOperationalModes
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_operational_modes_block_id import ModelsBranchesBranchIdCdhConopsOperationalModesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_conditions_ import ModelsBranchesBranchIdCdhConopsConditions
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_conditions_block_id import ModelsBranchesBranchIdCdhConopsConditionsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_group_conditions_ import ModelsBranchesBranchIdCdhConopsGroupConditions
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_group_conditions_block_id import ModelsBranchesBranchIdCdhConopsGroupConditionsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_space_targets_ import ModelsBranchesBranchIdCdhConopsSpaceTargets
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_space_targets_block_id import ModelsBranchesBranchIdCdhConopsSpaceTargetsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_celestial_targets_ import ModelsBranchesBranchIdCdhConopsCelestialTargets
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_celestial_targets_block_id import ModelsBranchesBranchIdCdhConopsCelestialTargetsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_ground_targets_ import ModelsBranchesBranchIdCdhConopsGroundTargets
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_ground_targets_block_id import ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_target_groups_ import ModelsBranchesBranchIdCdhConopsTargetGroups
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_target_groups_block_id import ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_types_ import ModelsBranchesBranchIdCdhDataDataTypes
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_types_block_id import ModelsBranchesBranchIdCdhDataDataTypesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_internal_data_interfaces_ import ModelsBranchesBranchIdCdhDataInternalDataInterfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_internal_data_interfaces_block_id import ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_passive_transmit_interfaces_ import ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_passive_transmit_interfaces_block_id import ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_cooperative_transmit_interfaces_ import ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_cooperative_transmit_interfaces_block_id import ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_receive_interfaces_ import ModelsBranchesBranchIdCdhDataReceiveInterfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_receive_interfaces_block_id import ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_busses_ import ModelsBranchesBranchIdCdhDataDataBusses
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_busses_block_id import ModelsBranchesBranchIdCdhDataDataBussesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_storage_ import ModelsBranchesBranchIdCdhDataDataStorage
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_storage_block_id import ModelsBranchesBranchIdCdhDataDataStorageBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_modes_ import ModelsBranchesBranchIdCdhDataDataModes
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_modes_block_id import ModelsBranchesBranchIdCdhDataDataModesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_modem_ import ModelsBranchesBranchIdCdhDataModem
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_modem_block_id import ModelsBranchesBranchIdCdhDataModemBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_antenna_ import ModelsBranchesBranchIdCdhDataAntenna
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_antenna_block_id import ModelsBranchesBranchIdCdhDataAntennaBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_laser_comm_module_ import ModelsBranchesBranchIdCdhDataLaserCommModule
from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_laser_comm_module_block_id import ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_ import ModelsBranchesBranchIdPowerSolarArrays
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_block_id import ModelsBranchesBranchIdPowerSolarArraysBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_panels_ import ModelsBranchesBranchIdPowerSolarArraysPanels
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_panels_block_id import ModelsBranchesBranchIdPowerSolarArraysPanelsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_cells_ import ModelsBranchesBranchIdPowerSolarArraysCells
from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_cells_block_id import ModelsBranchesBranchIdPowerSolarArraysCellsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_block_id import ModelsBranchesBranchIdPowerBatteriesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_packs_ import ModelsBranchesBranchIdPowerBatteriesPacks
from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_packs_block_id import ModelsBranchesBranchIdPowerBatteriesPacksBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_cells_ import ModelsBranchesBranchIdPowerBatteriesCells
from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_cells_block_id import ModelsBranchesBranchIdPowerBatteriesCellsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_power_processor_block_id import ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_bus_regulators_ import ModelsBranchesBranchIdPowerEpsBusRegulators
from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_bus_regulators_block_id import ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_heaters_ import ModelsBranchesBranchIdThermalTempControllersHeaters
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_heaters_block_id import ModelsBranchesBranchIdThermalTempControllersHeatersBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_coolers_ import ModelsBranchesBranchIdThermalTempControllersCoolers
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_coolers_block_id import ModelsBranchesBranchIdThermalTempControllersCoolersBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_states_ import ModelsBranchesBranchIdThermalTempControllersStates
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_states_block_id import ModelsBranchesBranchIdThermalTempControllersStatesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_thermal_interfaces_ import ModelsBranchesBranchIdThermalThermalInterfaces
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_thermal_interfaces_block_id import ModelsBranchesBranchIdThermalThermalInterfacesBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_thermal_interface_materials_ import ModelsBranchesBranchIdThermalThermalInterfaceMaterials
from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_thermal_interface_materials_block_id import ModelsBranchesBranchIdThermalThermalInterfaceMaterialsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_passive_ import ModelsBranchesBranchIdGncPointingModesPassive
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_passive_block_id import ModelsBranchesBranchIdGncPointingModesPassiveBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_lock_ import ModelsBranchesBranchIdGncPointingModesLock
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_lock_block_id import ModelsBranchesBranchIdGncPointingModesLockBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_max_secondary_align_ import ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlign
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_pointing_modes_max_secondary_align_block_id import ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlignBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_local_vectors_ import ModelsBranchesBranchIdGncReferenceVectorsLocalVectors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_local_vectors_block_id import ModelsBranchesBranchIdGncReferenceVectorsLocalVectorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_celestial_vectors_ import ModelsBranchesBranchIdGncReferenceVectorsCelestialVectors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_celestial_vectors_block_id import ModelsBranchesBranchIdGncReferenceVectorsCelestialVectorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_target_vectors_ import ModelsBranchesBranchIdGncReferenceVectorsTargetVectors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_target_vectors_block_id import ModelsBranchesBranchIdGncReferenceVectorsTargetVectorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_ import ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_block_id import ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_direction_sensors_ import ModelsBranchesBranchIdGncSensorsDirectionSensors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_direction_sensors_block_id import ModelsBranchesBranchIdGncSensorsDirectionSensorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_vector_sensors_ import ModelsBranchesBranchIdGncSensorsVectorSensors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_vector_sensors_block_id import ModelsBranchesBranchIdGncSensorsVectorSensorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_optical_attitude_sensors_ import ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_optical_attitude_sensors_block_id import ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_position_sensors_ import ModelsBranchesBranchIdGncSensorsPositionSensors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_position_sensors_block_id import ModelsBranchesBranchIdGncSensorsPositionSensorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_angular_velocity_sensors_ import ModelsBranchesBranchIdGncSensorsAngularVelocitySensors
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_angular_velocity_sensors_block_id import ModelsBranchesBranchIdGncSensorsAngularVelocitySensorsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_circ_fields_of_view_ import ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfView
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_circ_fields_of_view_block_id import ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfViewBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_rect_fields_of_view_ import ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfView
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_rect_fields_of_view_block_id import ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfViewBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_constraints_ import ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraints
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_sensors_fields_of_view_constraints_block_id import ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraintsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_magnetorquers_ import ModelsBranchesBranchIdGncActuatorsMagnetorquers
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_magnetorquers_block_id import ModelsBranchesBranchIdGncActuatorsMagnetorquersBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_reaction_wheels_ import ModelsBranchesBranchIdGncActuatorsReactionWheels
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_reaction_wheels_block_id import ModelsBranchesBranchIdGncActuatorsReactionWheelsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_thrusters_ import ModelsBranchesBranchIdGncActuatorsThrusters
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_actuators_thrusters_block_id import ModelsBranchesBranchIdGncActuatorsThrustersBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_triad_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriad
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_triad_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriadBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_averaging_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveraging
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_averaging_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveragingBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_mekf_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekf
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_mekf_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekfBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_ekf_ import ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkf
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_ekf_block_id import ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkfBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_gps_ import ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGps
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_gps_block_id import ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_sliding_mode_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_sliding_mode_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_pid_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_pid_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_thrust_control_static_thrust_control_ import ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControl
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_thrust_control_static_thrust_control_block_id import ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControlBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_ import ModelsBranchesBranchIdGncFuelReservoirs
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_block_id import ModelsBranchesBranchIdGncFuelReservoirsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherical_ import ModelsBranchesBranchIdGncFuelReservoirsTanksSpherical
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherical_block_id import ModelsBranchesBranchIdGncFuelReservoirsTanksSphericalBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherocylinder_ import ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinder
from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherocylinder_block_id import ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinderBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_agents_ import ModelsBranchesBranchIdAgents
from sedaro_base_client.apis.paths.models_branches_branch_id_agents_block_id import ModelsBranchesBranchIdAgentsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_clock_configs_ import ModelsBranchesBranchIdClockConfigs
from sedaro_base_client.apis.paths.models_branches_branch_id_clock_configs_block_id import ModelsBranchesBranchIdClockConfigsBlockId
from sedaro_base_client.apis.paths.models_branches_branch_id_orbits_ import ModelsBranchesBranchIdOrbits
from sedaro_base_client.apis.paths.models_branches_branch_id_orbits_block_id import ModelsBranchesBranchIdOrbitsBlockId
from sedaro_base_client.apis.paths.simulations_branches_branch_id_control_ import SimulationsBranchesBranchIdControl
from sedaro_base_client.apis.paths.simulations_branches_branch_id_control_job_id import SimulationsBranchesBranchIdControlJobId
from sedaro_base_client.apis.paths.data_ import Data
from sedaro_base_client.apis.paths.models_branches_branch_id import ModelsBranchesBranchId
from sedaro_base_client.apis.paths.models_branches_branch_idshare_auth_ import ModelsBranchesBranchIdshareAuth
from sedaro_base_client.apis.paths.models_branches_branch_idcommits_ import ModelsBranchesBranchIdcommits
from sedaro_base_client.apis.paths.models_branches_current_branch_id_merge_incoming_branch_id import ModelsBranchesCurrentBranchIdMergeIncomingBranchId
from sedaro_base_client.apis.paths.models_branches_branch_idcommitted_ import ModelsBranchesBranchIdcommitted
from sedaro_base_client.apis.paths.models_branches_branch_idsaved_ import ModelsBranchesBranchIdsaved

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SATELLITE_BLOCK_ID: ModelsBranchesBranchIdSystemSatelliteBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_BODYFRAMEVECTORS_: ModelsBranchesBranchIdSystemGeometryBodyFrameVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_BODYFRAMEVECTORS_BLOCK_ID: ModelsBranchesBranchIdSystemGeometryBodyFrameVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_: ModelsBranchesBranchIdSystemGeometrySurfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_BLOCK_ID: ModelsBranchesBranchIdSystemGeometrySurfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_MATERIALS_: ModelsBranchesBranchIdSystemGeometrySurfacesMaterials,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_MATERIALS_BLOCK_ID: ModelsBranchesBranchIdSystemGeometrySurfacesMaterialsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_: ModelsBranchesBranchIdSystemSubsystems,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_: ModelsBranchesBranchIdSystemSubsystemsComponents,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_: ModelsBranchesBranchIdSystemLoads,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_: ModelsBranchesBranchIdSystemLoadsStates,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsStatesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_: ModelsBranchesBranchIdCdhConopsOperationalModes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_BLOCK_ID: ModelsBranchesBranchIdCdhConopsOperationalModesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CONDITIONS_: ModelsBranchesBranchIdCdhConopsConditions,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CONDITIONS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsConditionsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUPCONDITIONS_: ModelsBranchesBranchIdCdhConopsGroupConditions,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUPCONDITIONS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroupConditionsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_SPACETARGETS_: ModelsBranchesBranchIdCdhConopsSpaceTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_SPACETARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsSpaceTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CELESTIALTARGETS_: ModelsBranchesBranchIdCdhConopsCelestialTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CELESTIALTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsCelestialTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_: ModelsBranchesBranchIdCdhConopsGroundTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_: ModelsBranchesBranchIdCdhConopsTargetGroups,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_: ModelsBranchesBranchIdCdhDataDataTypes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataTypesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_: ModelsBranchesBranchIdCdhDataInternalDataInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_: ModelsBranchesBranchIdCdhDataReceiveInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_: ModelsBranchesBranchIdCdhDataDataBusses,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataBussesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_: ModelsBranchesBranchIdCdhDataDataStorage,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataStorageBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_: ModelsBranchesBranchIdCdhDataDataModes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataModesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_: ModelsBranchesBranchIdCdhDataModem,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_BLOCK_ID: ModelsBranchesBranchIdCdhDataModemBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_: ModelsBranchesBranchIdCdhDataAntenna,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_BLOCK_ID: ModelsBranchesBranchIdCdhDataAntennaBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_: ModelsBranchesBranchIdCdhDataLaserCommModule,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_BLOCK_ID: ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_: ModelsBranchesBranchIdPowerSolarArrays,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_: ModelsBranchesBranchIdPowerSolarArraysPanels,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysPanelsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_CELLS_: ModelsBranchesBranchIdPowerSolarArraysCells,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysCellsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_: ModelsBranchesBranchIdPowerBatteriesPacks,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesPacksBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_: ModelsBranchesBranchIdPowerBatteriesCells,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesCellsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_POWERPROCESSOR_BLOCK_ID: ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_: ModelsBranchesBranchIdPowerEpsBusRegulators,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_BLOCK_ID: ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_: ModelsBranchesBranchIdThermalTempControllersHeaters,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersHeatersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_COOLERS_: ModelsBranchesBranchIdThermalTempControllersCoolers,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_COOLERS_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersCoolersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_STATES_: ModelsBranchesBranchIdThermalTempControllersStates,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_STATES_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersStatesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACES_: ModelsBranchesBranchIdThermalThermalInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACES_BLOCK_ID: ModelsBranchesBranchIdThermalThermalInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACEMATERIALS_: ModelsBranchesBranchIdThermalThermalInterfaceMaterials,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACEMATERIALS_BLOCK_ID: ModelsBranchesBranchIdThermalThermalInterfaceMaterialsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_PASSIVE_: ModelsBranchesBranchIdGncPointingModesPassive,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_PASSIVE_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesPassiveBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_LOCK_: ModelsBranchesBranchIdGncPointingModesLock,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_LOCK_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesLockBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_MAXSECONDARYALIGN_: ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlign,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_MAXSECONDARYALIGN_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlignBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_LOCALVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsLocalVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_LOCALVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsLocalVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_CELESTIALVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsCelestialVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_CELESTIALVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsCelestialVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsTargetVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsTargetVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETGROUPVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETGROUPVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_DIRECTIONSENSORS_: ModelsBranchesBranchIdGncSensorsDirectionSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_DIRECTIONSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsDirectionSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_VECTORSENSORS_: ModelsBranchesBranchIdGncSensorsVectorSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_VECTORSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsVectorSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_OPTICALATTITUDESENSORS_: ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_OPTICALATTITUDESENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_POSITIONSENSORS_: ModelsBranchesBranchIdGncSensorsPositionSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_POSITIONSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsPositionSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_ANGULARVELOCITYSENSORS_: ModelsBranchesBranchIdGncSensorsAngularVelocitySensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_ANGULARVELOCITYSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsAngularVelocitySensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CIRCFIELDSOFVIEW_: ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfView,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CIRCFIELDSOFVIEW_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfViewBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_RECTFIELDSOFVIEW_: ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfView,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_RECTFIELDSOFVIEW_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfViewBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CONSTRAINTS_: ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraints,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CONSTRAINTS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraintsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_MAGNETORQUERS_: ModelsBranchesBranchIdGncActuatorsMagnetorquers,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_MAGNETORQUERS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsMagnetorquersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_REACTIONWHEELS_: ModelsBranchesBranchIdGncActuatorsReactionWheels,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_REACTIONWHEELS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsReactionWheelsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_THRUSTERS_: ModelsBranchesBranchIdGncActuatorsThrusters,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_THRUSTERS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsThrustersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_TRIAD_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriad,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_TRIAD_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriadBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_AVERAGING_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveraging,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_AVERAGING_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveragingBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_MEKF_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekf,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_MEKF_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekfBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_EKF_: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkf,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_EKF_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkfBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGps,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_THRUSTCONTROL_STATICTHRUSTCONTROL_: ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControl,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_THRUSTCONTROL_STATICTHRUSTCONTROL_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControlBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_: ModelsBranchesBranchIdGncFuelReservoirs,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHERICAL_: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherical,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHERICAL_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsTanksSphericalBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHEROCYLINDER_: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinder,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHEROCYLINDER_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinderBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_: ModelsBranchesBranchIdAgents,
        PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_BLOCK_ID: ModelsBranchesBranchIdAgentsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_: ModelsBranchesBranchIdClockConfigs,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_BLOCK_ID: ModelsBranchesBranchIdClockConfigsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_ORBITS_: ModelsBranchesBranchIdOrbits,
        PathValues.MODELS_BRANCHES_BRANCH_ID_ORBITS_BLOCK_ID: ModelsBranchesBranchIdOrbitsBlockId,
        PathValues.SIMULATIONS_BRANCHES_BRANCH_ID_CONTROL_: SimulationsBranchesBranchIdControl,
        PathValues.SIMULATIONS_BRANCHES_BRANCH_ID_CONTROL_JOB_ID: SimulationsBranchesBranchIdControlJobId,
        PathValues.DATA_: Data,
        PathValues.MODELS_BRANCHES_BRANCH_ID: ModelsBranchesBranchId,
        PathValues.MODELS_BRANCHES_BRANCH_IDSHAREAUTH_: ModelsBranchesBranchIdshareAuth,
        PathValues.MODELS_BRANCHES_BRANCH_IDCOMMITS_: ModelsBranchesBranchIdcommits,
        PathValues.MODELS_BRANCHES_CURRENT_BRANCH_ID_MERGE_INCOMING_BRANCH_ID: ModelsBranchesCurrentBranchIdMergeIncomingBranchId,
        PathValues.MODELS_BRANCHES_BRANCH_IDCOMMITTED_: ModelsBranchesBranchIdcommitted,
        PathValues.MODELS_BRANCHES_BRANCH_IDSAVED_: ModelsBranchesBranchIdsaved,
    }
)

path_to_api = PathToApi(
    {
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SATELLITE_BLOCK_ID: ModelsBranchesBranchIdSystemSatelliteBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_BODYFRAMEVECTORS_: ModelsBranchesBranchIdSystemGeometryBodyFrameVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_BODYFRAMEVECTORS_BLOCK_ID: ModelsBranchesBranchIdSystemGeometryBodyFrameVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_: ModelsBranchesBranchIdSystemGeometrySurfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_BLOCK_ID: ModelsBranchesBranchIdSystemGeometrySurfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_MATERIALS_: ModelsBranchesBranchIdSystemGeometrySurfacesMaterials,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_GEOMETRY_SURFACES_MATERIALS_BLOCK_ID: ModelsBranchesBranchIdSystemGeometrySurfacesMaterialsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_: ModelsBranchesBranchIdSystemSubsystems,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_: ModelsBranchesBranchIdSystemSubsystemsComponents,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_: ModelsBranchesBranchIdSystemLoads,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_: ModelsBranchesBranchIdSystemLoadsStates,
        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsStatesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_: ModelsBranchesBranchIdCdhConopsOperationalModes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_BLOCK_ID: ModelsBranchesBranchIdCdhConopsOperationalModesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CONDITIONS_: ModelsBranchesBranchIdCdhConopsConditions,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CONDITIONS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsConditionsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUPCONDITIONS_: ModelsBranchesBranchIdCdhConopsGroupConditions,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUPCONDITIONS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroupConditionsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_SPACETARGETS_: ModelsBranchesBranchIdCdhConopsSpaceTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_SPACETARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsSpaceTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CELESTIALTARGETS_: ModelsBranchesBranchIdCdhConopsCelestialTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_CELESTIALTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsCelestialTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_: ModelsBranchesBranchIdCdhConopsGroundTargets,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_: ModelsBranchesBranchIdCdhConopsTargetGroups,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_: ModelsBranchesBranchIdCdhDataDataTypes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataTypesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_: ModelsBranchesBranchIdCdhDataInternalDataInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_: ModelsBranchesBranchIdCdhDataReceiveInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_: ModelsBranchesBranchIdCdhDataDataBusses,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataBussesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_: ModelsBranchesBranchIdCdhDataDataStorage,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataStorageBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_: ModelsBranchesBranchIdCdhDataDataModes,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataModesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_: ModelsBranchesBranchIdCdhDataModem,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_BLOCK_ID: ModelsBranchesBranchIdCdhDataModemBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_: ModelsBranchesBranchIdCdhDataAntenna,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_BLOCK_ID: ModelsBranchesBranchIdCdhDataAntennaBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_: ModelsBranchesBranchIdCdhDataLaserCommModule,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_BLOCK_ID: ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_: ModelsBranchesBranchIdPowerSolarArrays,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_: ModelsBranchesBranchIdPowerSolarArraysPanels,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysPanelsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_CELLS_: ModelsBranchesBranchIdPowerSolarArraysCells,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysCellsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_: ModelsBranchesBranchIdPowerBatteriesPacks,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesPacksBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_: ModelsBranchesBranchIdPowerBatteriesCells,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesCellsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_POWERPROCESSOR_BLOCK_ID: ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_: ModelsBranchesBranchIdPowerEpsBusRegulators,
        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_BLOCK_ID: ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_: ModelsBranchesBranchIdThermalTempControllersHeaters,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersHeatersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_COOLERS_: ModelsBranchesBranchIdThermalTempControllersCoolers,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_COOLERS_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersCoolersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_STATES_: ModelsBranchesBranchIdThermalTempControllersStates,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_STATES_BLOCK_ID: ModelsBranchesBranchIdThermalTempControllersStatesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACES_: ModelsBranchesBranchIdThermalThermalInterfaces,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACES_BLOCK_ID: ModelsBranchesBranchIdThermalThermalInterfacesBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACEMATERIALS_: ModelsBranchesBranchIdThermalThermalInterfaceMaterials,
        PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACEMATERIALS_BLOCK_ID: ModelsBranchesBranchIdThermalThermalInterfaceMaterialsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_PASSIVE_: ModelsBranchesBranchIdGncPointingModesPassive,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_PASSIVE_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesPassiveBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_LOCK_: ModelsBranchesBranchIdGncPointingModesLock,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_LOCK_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesLockBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_MAXSECONDARYALIGN_: ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlign,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_POINTINGMODES_MAXSECONDARYALIGN_BLOCK_ID: ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlignBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_LOCALVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsLocalVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_LOCALVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsLocalVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_CELESTIALVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsCelestialVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_CELESTIALVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsCelestialVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsTargetVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsTargetVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETGROUPVECTORS_: ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_REFERENCEVECTORS_TARGETGROUPVECTORS_BLOCK_ID: ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_DIRECTIONSENSORS_: ModelsBranchesBranchIdGncSensorsDirectionSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_DIRECTIONSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsDirectionSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_VECTORSENSORS_: ModelsBranchesBranchIdGncSensorsVectorSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_VECTORSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsVectorSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_OPTICALATTITUDESENSORS_: ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_OPTICALATTITUDESENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_POSITIONSENSORS_: ModelsBranchesBranchIdGncSensorsPositionSensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_POSITIONSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsPositionSensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_ANGULARVELOCITYSENSORS_: ModelsBranchesBranchIdGncSensorsAngularVelocitySensors,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_ANGULARVELOCITYSENSORS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsAngularVelocitySensorsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CIRCFIELDSOFVIEW_: ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfView,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CIRCFIELDSOFVIEW_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewCircFieldsOfViewBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_RECTFIELDSOFVIEW_: ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfView,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_RECTFIELDSOFVIEW_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfViewBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CONSTRAINTS_: ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraints,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_SENSORS_FIELDSOFVIEW_CONSTRAINTS_BLOCK_ID: ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraintsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_MAGNETORQUERS_: ModelsBranchesBranchIdGncActuatorsMagnetorquers,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_MAGNETORQUERS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsMagnetorquersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_REACTIONWHEELS_: ModelsBranchesBranchIdGncActuatorsReactionWheels,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_REACTIONWHEELS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsReactionWheelsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_THRUSTERS_: ModelsBranchesBranchIdGncActuatorsThrusters,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ACTUATORS_THRUSTERS_BLOCK_ID: ModelsBranchesBranchIdGncActuatorsThrustersBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_TRIAD_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriad,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_TRIAD_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriadBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_AVERAGING_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveraging,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_AVERAGING_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationAveragingBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_MEKF_: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekf,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDEDETERMINATION_MEKF_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekfBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_EKF_: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkf,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_EKF_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkfBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGps,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_THRUSTCONTROL_STATICTHRUSTCONTROL_: ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControl,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_THRUSTCONTROL_STATICTHRUSTCONTROL_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControlBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_: ModelsBranchesBranchIdGncFuelReservoirs,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHERICAL_: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherical,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHERICAL_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsTanksSphericalBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHEROCYLINDER_: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinder,
        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_FUELRESERVOIRS_TANKS_SPHEROCYLINDER_BLOCK_ID: ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinderBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_: ModelsBranchesBranchIdAgents,
        PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_BLOCK_ID: ModelsBranchesBranchIdAgentsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_: ModelsBranchesBranchIdClockConfigs,
        PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_BLOCK_ID: ModelsBranchesBranchIdClockConfigsBlockId,
        PathValues.MODELS_BRANCHES_BRANCH_ID_ORBITS_: ModelsBranchesBranchIdOrbits,
        PathValues.MODELS_BRANCHES_BRANCH_ID_ORBITS_BLOCK_ID: ModelsBranchesBranchIdOrbitsBlockId,
        PathValues.SIMULATIONS_BRANCHES_BRANCH_ID_CONTROL_: SimulationsBranchesBranchIdControl,
        PathValues.SIMULATIONS_BRANCHES_BRANCH_ID_CONTROL_JOB_ID: SimulationsBranchesBranchIdControlJobId,
        PathValues.DATA_: Data,
        PathValues.MODELS_BRANCHES_BRANCH_ID: ModelsBranchesBranchId,
        PathValues.MODELS_BRANCHES_BRANCH_IDSHAREAUTH_: ModelsBranchesBranchIdshareAuth,
        PathValues.MODELS_BRANCHES_BRANCH_IDCOMMITS_: ModelsBranchesBranchIdcommits,
        PathValues.MODELS_BRANCHES_CURRENT_BRANCH_ID_MERGE_INCOMING_BRANCH_ID: ModelsBranchesCurrentBranchIdMergeIncomingBranchId,
        PathValues.MODELS_BRANCHES_BRANCH_IDCOMMITTED_: ModelsBranchesBranchIdcommitted,
        PathValues.MODELS_BRANCHES_BRANCH_IDSAVED_: ModelsBranchesBranchIdsaved,
    }
)
