from sedaro_base_client.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_gps_.post import ApiForpost


class ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGps(
    ApiForpost,
):
    pass
