from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_heaters_.post import ApiForpost


class ModelsBranchesBranchIdThermalTempControllersHeaters(
    ApiForpost,
):
    pass
