from sedaro_base_client.paths.models_branches_branch_id_gnc_actuators_reaction_wheels_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_actuators_reaction_wheels_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncActuatorsReactionWheelsBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
