from sedaro_base_client.paths.models_branches_branch_id_gnc_sensors_optical_attitude_sensors_.post import ApiForpost


class ModelsBranchesBranchIdGncSensorsOpticalAttitudeSensors(
    ApiForpost,
):
    pass
