from sedaro_base_client.paths.models_branches_branch_id_gnc_sensors_fields_of_view_rect_fields_of_view_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_sensors_fields_of_view_rect_fields_of_view_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncSensorsFieldsOfViewRectFieldsOfViewBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
