from sedaro_base_client.paths.models_branches_branch_id_cdh_data_internal_data_interfaces_.post import ApiForpost


class ModelsBranchesBranchIdCdhDataInternalDataInterfaces(
    ApiForpost,
):
    pass
