from sedaro_base_client.paths.models_branches_branch_id_thermal_thermal_interface_materials_.post import ApiForpost


class ModelsBranchesBranchIdThermalThermalInterfaceMaterials(
    ApiForpost,
):
    pass
