from sedaro_base_client.paths.models_branches_branch_id_gnc_pointing_modes_max_secondary_align_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_pointing_modes_max_secondary_align_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlignBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
