from sedaro_base_client.paths.models_branches_branch_id_power_eps_power_processor_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId(
    ApiForpatch,
):
    pass
