from sedaro_base_client.paths.models_branches_branch_id_gnc_algorithms_thrust_control_static_thrust_control_.post import ApiForpost


class ModelsBranchesBranchIdGncAlgorithmsThrustControlStaticThrustControl(
    ApiForpost,
):
    pass
