from sedaro_base_client.paths.models_branches_branch_id_system_geometry_surfaces_materials_.post import ApiForpost


class ModelsBranchesBranchIdSystemGeometrySurfacesMaterials(
    ApiForpost,
):
    pass
