from sedaro_base_client.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_triad_.post import ApiForpost


class ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationTriad(
    ApiForpost,
):
    pass
