from sedaro_base_client.paths.models_branches_branch_id_system_geometry_body_frame_vectors_.post import ApiForpost


class ModelsBranchesBranchIdSystemGeometryBodyFrameVectors(
    ApiForpost,
):
    pass
