from sedaro_base_client.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_ekf_.post import ApiForpost


class ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationEkf(
    ApiForpost,
):
    pass
