from sedaro_base_client.paths.models_branches_branch_id_cdh_conops_ground_targets_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_cdh_conops_ground_targets_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
