from sedaro_base_client.paths.models_branches_branch_id_gnc_sensors_fields_of_view_constraints_.post import ApiForpost


class ModelsBranchesBranchIdGncSensorsFieldsOfViewConstraints(
    ApiForpost,
):
    pass
