from sedaro_base_client.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherical_.post import ApiForpost


class ModelsBranchesBranchIdGncFuelReservoirsTanksSpherical(
    ApiForpost,
):
    pass
