from sedaro_base_client.paths.models_branches_branch_id_gnc_sensors_angular_velocity_sensors_.post import ApiForpost


class ModelsBranchesBranchIdGncSensorsAngularVelocitySensors(
    ApiForpost,
):
    pass
