# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from sedaro_base_client.paths.models_branches_branch_id_thermal_thermal_interfaces_block_id import Api

from sedaro_base_client.paths import PathValues

path = PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_THERMALINTERFACES_BLOCK_ID