from sedaro_base_client.paths.models_branches_branch_id_gnc_reference_vectors_celestial_vectors_.post import ApiForpost


class ModelsBranchesBranchIdGncReferenceVectorsCelestialVectors(
    ApiForpost,
):
    pass
