from sedaro_base_client.paths.models_branches_branch_id_gnc_pointing_modes_max_secondary_align_.post import ApiForpost


class ModelsBranchesBranchIdGncPointingModesMaxSecondaryAlign(
    ApiForpost,
):
    pass
