from sedaro_base_client.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherocylinder_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_fuel_reservoirs_tanks_spherocylinder_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncFuelReservoirsTanksSpherocylinderBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
