from sedaro_base_client.paths.models_branches_branch_id_gnc_algorithms_attitude_determination_mekf_.post import ApiForpost


class ModelsBranchesBranchIdGncAlgorithmsAttitudeDeterminationMekf(
    ApiForpost,
):
    pass
