from sedaro_base_client.paths.models_branches_branch_id_power_solar_arrays_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_power_solar_arrays_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdPowerSolarArraysBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
